# Run tests in check section
%bcond_without check

# https://github.com/grpc-ecosystem/grpc-gateway
%global goipath         github.com/grpc-ecosystem/grpc-gateway
Version:                1.8.5

%global common_description %{expand:
The grpc-gateway is a plugin of the Google protocol buffers compiler protoc.
It reads protobuf service definitions and generates a reverse-proxy server
which translates a RESTful JSON API into gRPC. This server is generated
according to the google.api.http annotations in your service definitions.}

%gometa

Name:           golang-github-grpc-ecosystem-grpc-gateway
Release:        1%{?dist}
Summary:        GRPC to JSON proxy generator

# Upstream license specification: BSD-3-Clause and Apache-2.0
License:        BSD and ASL 2.0
URL:            %{gourl}
Source0:        %{gosource}
Source1:        glide.yaml
Source2:        glide.lock

BuildRequires:  golang(github.com/ghodss/yaml)
BuildRequires:  golang(github.com/golang/glog)
BuildRequires:  golang(github.com/golang/protobuf/descriptor)
BuildRequires:  golang(github.com/golang/protobuf/jsonpb)
BuildRequires:  golang(github.com/golang/protobuf/proto)
BuildRequires:  golang(github.com/golang/protobuf/protoc-gen-go/descriptor)
BuildRequires:  golang(github.com/golang/protobuf/protoc-gen-go/generator)
BuildRequires:  golang(github.com/golang/protobuf/protoc-gen-go/plugin)
BuildRequires:  golang(github.com/golang/protobuf/ptypes/any)
BuildRequires:  golang(github.com/golang/protobuf/ptypes/duration)
BuildRequires:  golang(github.com/golang/protobuf/ptypes/empty)
BuildRequires:  golang(github.com/golang/protobuf/ptypes/timestamp)
BuildRequires:  golang(github.com/golang/protobuf/ptypes/wrappers)
BuildRequires:  golang(github.com/rogpeppe/fastuuid)
BuildRequires:  golang(golang.org/x/net/context)
BuildRequires:  golang(google.golang.org/genproto/googleapis/api/annotations)
BuildRequires:  golang(google.golang.org/genproto/googleapis/api/httpbody)
BuildRequires:  golang(google.golang.org/genproto/googleapis/rpc/errdetails)
BuildRequires:  golang(google.golang.org/genproto/protobuf/field_mask)
BuildRequires:  golang(google.golang.org/grpc)
BuildRequires:  golang(google.golang.org/grpc/codes)
BuildRequires:  golang(google.golang.org/grpc/connectivity)
BuildRequires:  golang(google.golang.org/grpc/grpclog)
BuildRequires:  golang(google.golang.org/grpc/metadata)
BuildRequires:  golang(google.golang.org/grpc/status)
BuildRequires:  golang(gopkg.in/resty.v1)

%description
%{common_description}

%package devel
Summary:       %{summary}
BuildArch:     noarch

%description devel
%{common_description}

This package contains library source intended for
building other packages which use import path with
%{goipath} prefix.

%prep
%forgeautosetup -p1
cp %{SOURCE1} %{SOURCE2} .

%build
%gobuildroot
for cmd in protoc-gen-grpc-gateway protoc-gen-swagger; do
  %gobuild -o _bin/$(basename $cmd) %{goipath}/$cmd
done

%install
%goinstall glide.lock glide.yaml runtime/internal/stream_chunk.proto examples
install -m 0755 -vd                     %{buildroot}%{_bindir}
install -m 0755 -vp _bin/*              %{buildroot}%{_bindir}/

%if %{with check}
%check
%gochecks
%endif

%files
%license LICENSE.txt
%doc CHANGELOG.md CONTRIBUTING.md README.md docs/
%{_bindir}/*

%files devel -f devel.file-list
%license LICENSE.txt
%doc CHANGELOG.md CONTRIBUTING.md README.md docs/

%changelog
* Thu Apr 11 15:53:36 CET 2019 Robert-André Mauchin <zebob.m@gmail.com> - 1.8.5-1
- Release 1.8.5

* Tue Oct 23 2018 Nicolas Mailhot <nim@fedoraproject.org> - 1.0.0-0.13.git8cc3a55
- redhat-rpm-config-123 triggers bugs in gosetup, remove it from Go spec files as it’s just an alias
- https://lists.fedoraproject.org/archives/list/devel@lists.fedoraproject.org/message/RWD5YATAYAFWKIDZBB7EB6N5DAO4ZKFM/

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-0.12.git8cc3a55
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 12 2018 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.11.git8cc3a55
- Upload glide files

* Thu Mar 08 2018 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.10.git8cc3a55
- Bump to 8cc3a55af3bcf171a1c23a90c4df9cf591706104
  related: #1405682

* Tue Feb 20 2018 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.9.git18d1596
- Autogenerate some parts using the new macros

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-0.8.git18d1596
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Sep 22 2017 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.7.git18d1596
- Bump to upstream 18d159699f2e83fc5bb9ef2f79465ca3f3122676
  related: #1405682

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-0.6.git84398b9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-0.5.git84398b9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Thu Mar 16 2017 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.4.git84398b9
- Bump to upstream 84398b94e188ee336f307779b57b3aa91af7063c
  related: #1405682

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0-0.3.gitf52d055
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Dec 17 2016 Jan Chaloupka <jchaloup@redhat.com> - 1.0.0-0.2.gitf52d055
- Polish the spec file
  resolves: #1405682

* Tue Aug 02 2016 jchaloup <jchaloup@redhat.com> - 1.0.0-0.1.gitf52d055
- First package for Fedora
  resolves: #1362419
